import * as pulumi from "@pulumi/pulumi";
/**
 * Use this data source to get the Group ID of the `Everyone` group in Wavefront.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as wavefront from "@pulumi/wavefront";
 *
 * // Get the default user group "Everyone"
 * const everyoneGroup = wavefront.getDefaultUserGroup({});
 * ```
 */
export declare function getDefaultUserGroup(opts?: pulumi.InvokeOptions): Promise<GetDefaultUserGroupResult>;
/**
 * A collection of values returned by getDefaultUserGroup.
 */
export interface GetDefaultUserGroupResult {
    /**
     * Set to the Group ID of the `Everyone` group, suitable for referencing
     * in other resources that support group memberships.
     */
    readonly groupId: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
}
/**
 * Use this data source to get the Group ID of the `Everyone` group in Wavefront.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as wavefront from "@pulumi/wavefront";
 *
 * // Get the default user group "Everyone"
 * const everyoneGroup = wavefront.getDefaultUserGroup({});
 * ```
 */
export declare function getDefaultUserGroupOutput(opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetDefaultUserGroupResult>;
