import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * Use this data source to get information about all Wavefront events.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as wavefront from "@pulumi/wavefront";
 *
 * // Get the information about all events
 * const example = wavefront.getEvents({
 *     limit: 10,
 *     offset: 0,
 *     latestStartTimeEpochMillis: 1665427195,
 *     earliestStartTimeEpochMillis: 1665427195,
 * });
 * ```
 */
export declare function getEvents(args: GetEventsArgs, opts?: pulumi.InvokeOptions): Promise<GetEventsResult>;
/**
 * A collection of arguments for invoking getEvents.
 */
export interface GetEventsArgs {
    /**
     * The earliest start time in epoch milliseconds.
     */
    earliestStartTimeEpochMillis: number;
    /**
     * The latest start time in epoch milliseconds.
     */
    latestStartTimeEpochMillis: number;
    /**
     * Limit is the maximum number of results to be returned. Defaults to 100.
     */
    limit?: number;
    /**
     * Offset is the offset from the first result to be returned. Defaults to 0.
     */
    offset?: number;
}
/**
 * A collection of values returned by getEvents.
 */
export interface GetEventsResult {
    /**
     * Earliest start time in epoch milliseconds.
     */
    readonly earliestStartTimeEpochMillis: number;
    /**
     * List of all events in Wavefront. For each event you will see a list of attributes.
     */
    readonly events: outputs.GetEventsEvent[];
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Latest start time in epoch milliseconds.
     */
    readonly latestStartTimeEpochMillis: number;
    readonly limit?: number;
    readonly offset?: number;
}
/**
 * Use this data source to get information about all Wavefront events.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as wavefront from "@pulumi/wavefront";
 *
 * // Get the information about all events
 * const example = wavefront.getEvents({
 *     limit: 10,
 *     offset: 0,
 *     latestStartTimeEpochMillis: 1665427195,
 *     earliestStartTimeEpochMillis: 1665427195,
 * });
 * ```
 */
export declare function getEventsOutput(args: GetEventsOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetEventsResult>;
/**
 * A collection of arguments for invoking getEvents.
 */
export interface GetEventsOutputArgs {
    /**
     * The earliest start time in epoch milliseconds.
     */
    earliestStartTimeEpochMillis: pulumi.Input<number>;
    /**
     * The latest start time in epoch milliseconds.
     */
    latestStartTimeEpochMillis: pulumi.Input<number>;
    /**
     * Limit is the maximum number of results to be returned. Defaults to 100.
     */
    limit?: pulumi.Input<number>;
    /**
     * Offset is the offset from the first result to be returned. Defaults to 0.
     */
    offset?: pulumi.Input<number>;
}
