import * as pulumi from "@pulumi/pulumi";
/**
 * Use this data source to get information for a given user by email from Wavefront.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as wavefront from "@pulumi/wavefront";
 *
 * // Get the info for user "example.user@example.com"
 * const example = wavefront.getUser({
 *     email: "example.user@example.com",
 * });
 * ```
 */
export declare function getUser(args: GetUserArgs, opts?: pulumi.InvokeOptions): Promise<GetUserResult>;
/**
 * A collection of arguments for invoking getUser.
 */
export interface GetUserArgs {
    /**
     * The email associated with the user data to be fetched.
     */
    email: string;
}
/**
 * A collection of values returned by getUser.
 */
export interface GetUserResult {
    /**
     * The customer the user is associated with.
     */
    readonly customer: string;
    readonly email: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * When the user last logged in to Wavefront.
     */
    readonly lastSuccessfulLogin: number;
    /**
     * List of permissions granted to a user.
     */
    readonly permissions: string[];
    /**
     * List of User Group Ids the user is a member of.
     */
    readonly userGroupIds: string[];
}
/**
 * Use this data source to get information for a given user by email from Wavefront.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as wavefront from "@pulumi/wavefront";
 *
 * // Get the info for user "example.user@example.com"
 * const example = wavefront.getUser({
 *     email: "example.user@example.com",
 * });
 * ```
 */
export declare function getUserOutput(args: GetUserOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetUserResult>;
/**
 * A collection of arguments for invoking getUser.
 */
export interface GetUserOutputArgs {
    /**
     * The email associated with the user data to be fetched.
     */
    email: pulumi.Input<string>;
}
